summaryrefslogtreecommitdiffstats
path: root/libk9copy/k9dvdtitle.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
commitb0e912c8b3d02a518fedda28c3180eb4794a7520 (patch)
tree07d344862562fab58cbe2df39d13d16f2e4d2bea /libk9copy/k9dvdtitle.cpp
parent4d695ec81fe4d4335ee82c7a9346ad9c9e144ecc (diff)
downloadk9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.tar.gz
k9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.zip
TQt4 convert k9copy
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k9copy@1233843 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libk9copy/k9dvdtitle.cpp')
-rw-r--r--libk9copy/k9dvdtitle.cpp92
1 files changed, 46 insertions, 46 deletions
diff --git a/libk9copy/k9dvdtitle.cpp b/libk9copy/k9dvdtitle.cpp
index acd2bdb..21a8e79 100644
--- a/libk9copy/k9dvdtitle.cpp
+++ b/libk9copy/k9dvdtitle.cpp
@@ -20,14 +20,14 @@
#include "k9dvdtitle.h"
-#include <qapplication.h>
+#include <tqapplication.h>
#include <string.h>
#include <sys/stat.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
-#include <qvaluelist.h>
+#include <tqvaluelist.h>
#include "k9dvdtitleset.h"
#include "k9titleencopt.h"
@@ -37,17 +37,17 @@ k9DVDAudioStream::k9DVDAudioStream() {
selected=false;
}
-/** Read property of QString format. */
-const QString& k9DVDAudioStream::getformat() {
+/** Read property of TQString format. */
+const TQString& k9DVDAudioStream::getformat() {
return format;
}
-/** Read property of QString frequency. */
-const QString& k9DVDAudioStream::getfrequency() {
+/** Read property of TQString frequency. */
+const TQString& k9DVDAudioStream::getfrequency() {
return frequency;
}
-/** Read property of QString quantization. */
-const QString& k9DVDAudioStream::getquantization() {
+/** Read property of TQString quantization. */
+const TQString& k9DVDAudioStream::getquantization() {
return quantization;
}
/** Read property of int channels. */
@@ -58,8 +58,8 @@ const int& k9DVDAudioStream::getchannels() {
const int& k9DVDAudioStream::getappMode() {
return appMode;
}
-/** Read property of QString content. */
-const QString& k9DVDAudioStream::getcontent() {
+/** Read property of TQString content. */
+const TQString& k9DVDAudioStream::getcontent() {
return content;
}
@@ -84,12 +84,12 @@ void k9DVDAudioStream::setselected( const bool& _newVal) {
title->selectChapters( after);
}
-/** Read property of QString langCod. */
-const QString& k9DVDAudioStream::getlangCod() {
+/** Read property of TQString langCod. */
+const TQString& k9DVDAudioStream::getlangCod() {
return langCod;
}
-/** Read property of QString language. */
-const QString& k9DVDAudioStream::getlanguage() {
+/** Read property of TQString language. */
+const TQString& k9DVDAudioStream::getlanguage() {
return language;
}
@@ -109,20 +109,20 @@ k9DVDSubtitle::k9DVDSubtitle() {
}
-/** Read property of QString langCod. */
-const QString& k9DVDSubtitle::getlangCod() {
+/** Read property of TQString langCod. */
+const TQString& k9DVDSubtitle::getlangCod() {
return langCod;
}
-/** Read property of QString language. */
-const QString& k9DVDSubtitle::getlanguage() {
+/** Read property of TQString language. */
+const TQString& k9DVDSubtitle::getlanguage() {
return language;
}
/** Read property of int num. */
const int& k9DVDSubtitle::getnum() {
return num;
}
-/** Read property of QString content. */
-const QString& k9DVDSubtitle::getcontent() {
+/** Read property of TQString content. */
+const TQString& k9DVDSubtitle::getcontent() {
return content;
}
@@ -153,7 +153,7 @@ k9DVDTitle * k9DVDSubtitle::gettitle() {
/*!
\fn k9DVDSubtitle::getID()
*/
-QValueList<int>& k9DVDSubtitle::getID() {
+TQValueList<int>& k9DVDSubtitle::getID() {
return id;
}
@@ -219,7 +219,7 @@ const int& k9DVDTitle::getsubPictureCount() {
return subPictureCount;
}
/** Read property of int streamCount. */
-const QTime& k9DVDTitle::getlength() {
+const TQTime& k9DVDTitle::getlength() {
return length;
}
@@ -283,11 +283,11 @@ const float k9DVDTitle::gettotalvideosize_mb() {
}
-QTime k9DVDTitle::gettotallength() {
- QTime totalTime=getlength();
+TQTime k9DVDTitle::gettotallength() {
+ TQTime totalTime=getlength();
for (uint i=0;i<m_titles.count();i++) {
k9DVDTitle *tmp=m_titles.at(i);
- QTime t;
+ TQTime t;
int msecs= t.msecsTo(tmp->getlength());
totalTime=totalTime.addMSecs(msecs);
}
@@ -295,11 +295,11 @@ QTime k9DVDTitle::gettotallength() {
}
-QTime k9DVDTitle::getSelectedLength() {
- QTime totalTime(0,0);
+TQTime k9DVDTitle::getSelectedLength() {
+ TQTime totalTime(0,0);
for (k9DVDChapter *chapter=chapters.first();chapter;chapter=chapters.next()) {
if (chapter->getSelected()) {
- QTime t;
+ TQTime t;
int msecs= t.msecsTo(chapter->getlength());
totalTime=totalTime.addMSecs(msecs);
}
@@ -308,10 +308,10 @@ QTime k9DVDTitle::getSelectedLength() {
for (uint i=0;i<m_titles.count();i++) {
k9DVDTitle *tmp=m_titles.at(i);
- QPtrList <k9DVDChapter> tchapters=tmp->getChapters();
+ TQPtrList <k9DVDChapter> tchapters=tmp->getChapters();
for (k9DVDChapter *chapter=tchapters.first();chapter;chapter=tchapters.next()) {
if (chapter->getSelected()) {
- QTime t;
+ TQTime t;
int msecs= t.msecsTo(chapter->getlength());
totalTime=totalTime.addMSecs(msecs);
}
@@ -340,28 +340,28 @@ const int& k9DVDTitle::getTTN() {
const float& k9DVDTitle::getFPS() {
return FPS;
}
-/** Read property of QString format. */
-const QString& k9DVDTitle::getformat() {
+/** Read property of TQString format. */
+const TQString& k9DVDTitle::getformat() {
return format;
}
-/** Read property of QString aspectRatio. */
-const QString& k9DVDTitle::getaspectRatio() {
+/** Read property of TQString aspectRatio. */
+const TQString& k9DVDTitle::getaspectRatio() {
return aspectRatio;
}
-/** Read property of QString width. */
-const QString& k9DVDTitle::getwidth() {
+/** Read property of TQString width. */
+const TQString& k9DVDTitle::getwidth() {
return width;
}
-/** Read property of QString height. */
-const QString& k9DVDTitle::getheight() {
+/** Read property of TQString height. */
+const TQString& k9DVDTitle::getheight() {
return height;
}
-/** Read property of QString palette. */
-void k9DVDTitle::getpalette(int i,QString & c) {
+/** Read property of TQString palette. */
+void k9DVDTitle::getpalette(int i,TQString & c) {
c=*palette.at(i);
}
-/** Read property of QString DF. */
-const QString& k9DVDTitle::getDF() {
+/** Read property of TQString DF. */
+const TQString& k9DVDTitle::getDF() {
return DF;
}
/** Read property of int angleCount. */
@@ -406,12 +406,12 @@ bool k9DVDTitle::isSelected() {
}
-/** Read property of QString name. */
-const QString& k9DVDTitle::getname() {
+/** Read property of TQString name. */
+const TQString& k9DVDTitle::getname() {
return name;
}
-/** Write property of QString name. */
-void k9DVDTitle::setname( const QString& _newVal) {
+/** Write property of TQString name. */
+void k9DVDTitle::setname( const TQString& _newVal) {
name = _newVal;
}